@@ -3,6 +3,7 @@ package Net::Whois::RIPE;
 use 5.006;
 use warnings;
 use strict;
+use Net::Whois::Generic;
 use IO::Socket::INET;
 use IO::Select;
 use Iterator;
@@ -27,11 +28,11 @@ Net::Whois::RIPE - a pure-Perl implementation of the RIPE Database client.
 
 =head1 VERSION
 
-Version 2.005002
+Version 2.005003
 
 =cut
 
-our $VERSION = 2.005002;
+our $VERSION = 2.005003;
 
 =head1 SYNOPSIS
 
@@ -49,17 +50,11 @@ The usage should remain mostly the same:
   my $whois = Net::Whois::RIPE->new( %options );
   $iterator = $whois->query( 'AS333' );
 
-If you prefer to manipulate full-fledged objects you can now use
-
-  use Net::Whois::Object;
-
-  my @objects = Net::Whois::Object->query( 'AS333' );
-
 From version 2.005000 you can also use the  Net::Whois::Generic interface 
 that mimics Net::Whois::Object while offering access to data from other sources
 than RIPE (AFRINIC, APNIC)
 
-  use Net::Whois::Object;
+  use Net::Whois::RIPE;
 
   my @objects = Net::Whois::Generic->query( 'ORG-AFNC1-AFRINIC' );
 
